<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:landxml="http://www.landxml.org/schema/LandXML-1.2"  xmlns:n1="http://www.landxml.org/schema/LandXML-1.2" xmlns:hexagon="http://xml.hexagon.com/schema/HeXML-1.6" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:variable name="fileExt" select="'html'"/>
<xsl:variable name="fileDesc" select="'Stakeout results cut sheet.  Uses Ellipsoidal heights. Add images to export folder.'"/>
<xsl:template match="/">
 
<html>
	<head>
		<title>Leica SmartWorx Viva Stakeout Report</title>
			<style><!-- this style section is a css section defining how html elements will be displayed.-->
				body {	font-family:verdana,arial,sans-serif;
				font-size:10.5pt;
				margin-left:30px;
				margin-right:30px;
				color:"#333333";}

				p { font-family:verdana,arial,sans-serif;
				 font-size:10.5pt;}

				h2 {	margin-top:18.0pt;
				margin-right:0cm;
				margin-bottom:6.0pt;
				margin-left:0cm;
				page-break-after:avoid;
				font-size:18.0pt;
				font-family:Arial;}

				h3 {	margin-top:12.0pt;
				margin-right:0cm;
				margin-bottom:6.0pt;
				margin-left:0cm;
				mso-pagination:widow-orphan;
				page-break-after:avoid;
				font-size:14.0pt;
				font-family:Arial;
				font-weight:normal;}

				table.sample {	border-width:50px;}

				table.sample th {	border-width:1px;
				padding:5px;
				border-style:dashed;
				border-color:grey;
				width:400px;
				font-family:verdana,arial,sans-serif;
				font-size:10.5pt;
				text-align:center;}

				table.sample td {	border-width:1px;
				padding:5px;
				border-style:dashed;
				border-color:grey;
				width:400px;
				font-family:verdana,arial,sans-serif;
				font-size:10.5pt;
				align:texttop}
			</style>
	</head>
		<body>
		<img src="leica.png" align="right" alt="Sample Leica SmartWorx Viva Image"></img><!-- displays an image at top right of page.  Change path to your own Logo.-->
		<h2>Stakeout Results</h2>
		<table>
			<tr>
			<p>
				<td align="right"><h3><b>Date of Survey:</b></h3></td>
				<td align="right"><h3><xsl:value-of select="substring-before(//landxml:CgPoint/@timeStamp,'T')"/></h3></td>
			</p>    
			</tr>
			<tr>
			<p>
				<td align="right"><h3><b>Time of Survey:</b></h3></td>
				<td align="right"><h3><xsl:value-of select="substring-after(//landxml:CgPoint/@timeStamp,'T')"/></h3></td>
			</p>    
			</tr>
			<tr>
			<p>
				<td align="right"><h3><b>Working Job:</b></h3></td>
				<td align="right"><h3><xsl:value-of select="substring-before(//landxml:SurveyHeader/@name,'_')"/></h3></td>
			</p>    
			</tr>
			<tr>
			<p>
				<td align="right"><h3><b>Points staked:</b></h3></td>
				<td align="right"><h3><xsl:value-of select="count(//hexagon:ApplicationStakeout/@StakedPointID )"/></h3></td>
			</p>    
			</tr>
		 </table>
		
		<table class="sample">
			<tr bgcolor="#f2f2f2"><!-- Color of top row in table, overrides style setting.-->
			<p>
			 <th>Staked point ID</th>
			 <th>Design easting</th>
			 <th>Design northing</th>
			 <th>Design height</th>
			 <th>Staked easting</th>
			 <th>Staked northing</th>
			 <th>Staked height</th>
             <th>Cut / fill</th>
             <th>Height difference (tolerance +/-0.005m)</th><!-- Tolerance of difference.-->
	        </p>    
	        </tr>
	        
			<xsl:for-each select="//hexagon:ApplicationStakeout"><!-- This starts the outer loop, only catching Application Stakeout results.-->
				<xsl:variable name="designht" select="@DesignPointEllHeight"/> 
			<tr>	  
		       <td><xsl:value-of select="@StakedPointID"/></td>
		       <td align="right"><xsl:value-of select='format-number(@DesignPointEasting, "#.000")'/></td>
				<td align="right"><xsl:value-of select='format-number(@DesignPointNorthing, "#.000")'/></td>
				<td align="right"><xsl:value-of select='format-number(@DesignPointEllHeight, "#0.000")'/></td>
				
				<xsl:variable name="pointId" select="@StakedPointID"/>
			<xsl:for-each select="//hexagon:Point">
				<xsl:if test="@uniqueID= $pointId"><!-- Checks if Staked Point ID matches Point ID.  Needed to get further information about the points.-->		
				<xsl:for-each select="hexagon:Coordinates"><!-- Start loop to get easting, northing and height.-->
					<xsl:for-each select="hexagon:Local">
						<xsl:for-each select="hexagon:Grid">
			<td><xsl:value-of select='format-number(@e, "#.000")'/></td>
			<td><xsl:value-of select='format-number(@n, "#.000")'/></td>
			<td><xsl:value-of select='format-number(@hghtE, "#0.000")'/></td>
							<xsl:variable name="stakedht" select="@hghtE"/>
							<xsl:variable name="heightdifference" select="$stakedht - $designht"/> <!-- Subtracts design height from staked height.-->	
					
					<xsl:choose><!-- tests if height difference is a negative or postive figure.-->
						<xsl:when test="$heightdifference &lt;0">
			<td align="right"><xsl:value-of select="'Fill'"/></td>
						</xsl:when>
						<xsl:when test="$heightdifference &gt;=0">
			<td align="right"><xsl:value-of select="'Cut'"/></td>
						</xsl:when>
						<xsl:otherwise>
			<td align="right"><xsl:value-of select="'Design height and Staked height are the same'"/></td>
						</xsl:otherwise>
					</xsl:choose>

					<xsl:choose><!-- tests if height difference is outside of defined tolerance-->
						<xsl:when test="$heightdifference &gt;0.005">
			<td align="right"><img src="out_tolerance.png" height="18" align="left"></img><xsl:value-of select='format-number($heightdifference, "#0.000")' /></td>
						</xsl:when>
						<xsl:when test="$heightdifference &lt;=-0.005">
			<td align="right"><img src="out_tolerance.png" height="18" align="left"></img><xsl:value-of select='format-number($heightdifference, "#0.000")' /></td>
						</xsl:when>
						<xsl:otherwise>
			<td align="right"><img src="in_tolerance.png" height="18" align="left"></img><xsl:value-of select='format-number($heightdifference, "#0.000")'/></td>
						</xsl:otherwise>
					</xsl:choose>

					</xsl:for-each>
				 </xsl:for-each>
			</xsl:for-each>

		</xsl:if>
</xsl:for-each>

		</tr>
</xsl:for-each>

</table>
 </body>  
 </html>
  
</xsl:template>
</xsl:stylesheet>